# Ziggy Pydust

A framework for writing and packaging native Python extension modules written in Zig.

* Package Python extension modules written in Zig.
* Pytest plugin to discover and run Zig tests.
* Comptime argument wrapping / unwrapping for interop with native Zig types.

## Compatibility

Pydust supports:

* [Zig 0.11.0](https://ziglang.org/download/0.11.0/release-notes.html)
* [CPython >=3.11](https://docs.python.org/3.11/c-api/stable.html)

Please reach out if you're interested in helping us to expand compatibility.

## Contributing

We welcome contributions! Pydust is in its early stages so there is lots of low hanging
fruit when it comes to contributions.

* Assist other Pydust users with GitHub issues or discussions.
* Suggest or implement features, fix bugs, fix performance issues.
* Improve our documentation.
* Write articles or other content demonstrating how you have used Pydust.

## License

Pydust is released under the [Apache-2.0 license](https://opensource.org/licenses/APACHE-2.0).
